@@ -118,8 +118,8 @@ def main(config: dict, user_code: callable):
 	if config['merge_libs']:
 		weld_dp = f"{config['build_folder']}/{config['datapack_name_simple']}_datapack_with_libs.zip"
 		weld_rp = f"{config['build_folder']}/{config['datapack_name_simple']}_resource_pack_with_libs.zip"
-		weld_datapack(weld_dp)
-		weld_resource_pack(weld_rp)
+		weld_datapack(config, weld_dp)
+		weld_resource_pack(config, weld_rp)
 		try:
 			shutil.copy(weld_rp, resourcepack_dest)
 		except OSError:
